pub struct StandardAnalyzer { /* private fields */ }Expand description
Runs one tokenizer followed by filters in insertion order.
See crates/khive-text/docs/api/analyzer-pipeline.md.
Implementations
Sourceimpl StandardAnalyzer
impl StandardAnalyzer
Sourcepub fn with_tokenizer(tokenizer: impl Tokenizer + 'static) -> Self
pub fn with_tokenizer(tokenizer: impl Tokenizer + 'static) -> Self
Create an analyzer with the given tokenizer and no filters.
Sourcepub fn filter(self, f: impl TokenFilter + 'static) -> Self
pub fn filter(self, f: impl TokenFilter + 'static) -> Self
Append a filter to the pipeline. Filters run in insertion order.